==> mongodb-6.0.27.gh.tar.gz: mongo-r6.0.27/src/mongo/s/catalog_cache_mock.h <==
/**
 *    Copyright (C) 2021-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/s/catalog_cache.h"
#include "mongo/s/catalog_cache_loader_mock.h"

namespace mongo {

/**
 * Mocks the metadata refresh results with settable return values. The purpose of this class is to
 * facilitate testing of classes that use a CatalogCacheLoader.
 */
class CatalogCacheMock final : public CatalogCache {
    CatalogCacheMock(const CatalogCacheMock&) = delete;
    CatalogCacheMock& operator=(const CatalogCacheMock&) = delete;

public:
    CatalogCacheMock(ServiceContext* context, CatalogCacheLoaderMock& loader);
    ~CatalogCacheMock() = default;

    StatusWith<ChunkManager> getCollectionRoutingInfo(OperationContext* opCtx,
                                                      const NamespaceString& nss,
                                                      bool allowLocks) override;

    void setChunkManagerReturnValue(StatusWith<ChunkManager> statusWithChunks);
    void clearChunkManagerReturnValue();

    static std::unique_ptr<CatalogCacheMock> make();

    static const Status kChunkManagerInternalErrorStatus;

private:
    StatusWith<ChunkManager> _swChunkManagerReturnValue{kChunkManagerInternalErrorStatus};
};

}  // namespace mongo

==> mongodb-7.0.23.gh.tar.gz: mongo-r7.0.23/src/mongo/s/catalog_cache_mock.h <==
/**
 *    Copyright (C) 2021-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/s/catalog_cache.h"
#include "mongo/s/catalog_cache_loader_mock.h"

namespace mongo {

/**
 * Mocks the metadata refresh results with settable return values. The purpose of this class is to
 * facilitate testing of classes that use a CatalogCacheLoader.
 */
class CatalogCacheMock final : public CatalogCache {
    CatalogCacheMock(const CatalogCacheMock&) = delete;
    CatalogCacheMock& operator=(const CatalogCacheMock&) = delete;

public:
    CatalogCacheMock(ServiceContext* context, CatalogCacheLoaderMock& loader);
    ~CatalogCacheMock() = default;

    StatusWith<CollectionRoutingInfo> getCollectionRoutingInfo(OperationContext* opCtx,
                                                               const NamespaceString& nss,
                                                               bool allowLocks) override;

    void setDatabaseReturnValue(const DatabaseName& dbName, CachedDatabaseInfo databaseInfo);

    StatusWith<CachedDatabaseInfo> getDatabase(OperationContext* opCtx, StringData dbName) override;

    void setChunkManagerReturnValue(StatusWith<ChunkManager> statusWithChunks);
    void clearChunkManagerReturnValue();

    static std::unique_ptr<CatalogCacheMock> make();

    static const Status kChunkManagerInternalErrorStatus;

    static CachedDatabaseInfo makeDatabaseInfo(const DatabaseName& dbName,
                                               const ShardId& dbPrimaryShard,
                                               const DatabaseVersion& dbVersion);

private:
    stdx::unordered_map<DatabaseName, CachedDatabaseInfo> _dbCache;

    StatusWith<ChunkManager> _swChunkManagerReturnValue{kChunkManagerInternalErrorStatus};
};

}  // namespace mongo
